---------------------
PatchSet 4969 
Date: 2007/07/11 03:14:59
Author: amosjeffries
Branch: docs
Tag: (none) 
Log:
Some Documentation

Members: 
	src/URL.h:1.1->1.1.24.1 
	src/dnsserver.cc:1.9->1.9.14.1 
	src/squid.h:1.33->1.33.2.1 
	src/ssl_support.h:1.6->1.6.10.1 

Index: squid3/src/URL.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/URL.h,v
retrieving revision 1.1
retrieving revision 1.1.24.1
diff -u -r1.1 -r1.1.24.1
--- squid3/src/URL.h	12 May 2006 13:49:56 -0000	1.1
+++ squid3/src/URL.h	11 Jul 2007 03:14:59 -0000	1.1.24.1
@@ -1,6 +1,6 @@
 
 /*
- * $Id: URL.h,v 1.1 2006/05/12 13:49:56 squidadm Exp $
+ * $Id: URL.h,v 1.1.24.1 2007/07/11 03:14:59 amosjeffries Exp $
  *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -38,7 +38,8 @@
 #include "MemPool.h"
 #include "URLScheme.h"
 
-/* The URL class represents a UniformResourceLocation */
+/** \ingroup POD */
+/** The URL class represents a Uniform Resource Location */
 
 class URL
 {
@@ -51,19 +52,23 @@
     URLScheme const & getScheme() const {return scheme; }
 
 private:
-    /* the scheme of this URL. This has the 'type code' smell about it.
+    /**
+     * \par
+     * The scheme of this URL. This has the 'type code' smell about it.
      * In future we may want to make the methods that dispatch based on 
      * the scheme virtual and have a class per protocol. 
-     * on the other hand, having Protocol as an explicit concept is useful,
+     * \par
+     * On the other hand, having Protocol as an explicit concept is useful,
      * see for instance the ACLProtocol acl type. One way to represent this
      * is to have one prototype URL with no host etc for each scheme, 
      * another is to have an explicit scheme class, and then each URL class
      * could be a subclass of the scheme. Another way is one instance of 
      * a URLScheme class instance for each URLScheme we support, and one URL
      * class for each manner of treating the scheme : a Hierarchical URL, a
-     * non-hierarchical URL etc. 
+     * non-hierarchical URL etc.
+     * \par
      * Deferring the decision, its a type code for now. RBC 20060507.
-     *
+     * \par
      * In order to make taking any of these routes easy, scheme is private 
      * and immutable, only settable at construction time,
      */
Index: squid3/src/dnsserver.cc
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/dnsserver.cc,v
retrieving revision 1.9
retrieving revision 1.9.14.1
diff -u -r1.9 -r1.9.14.1
--- squid3/src/dnsserver.cc	13 Aug 2006 20:50:47 -0000	1.9
+++ squid3/src/dnsserver.cc	11 Jul 2007 03:14:59 -0000	1.9.14.1
@@ -1,6 +1,6 @@
 
 /*
- * $Id: dnsserver.cc,v 1.9 2006/08/13 20:50:47 squidadm Exp $
+ * $Id: dnsserver.cc,v 1.9.14.1 2007/07/11 03:14:59 amosjeffries Exp $
  *
  * DEBUG: section 0     DNS Resolver
  * AUTHOR: Harvest Derived
@@ -162,7 +162,8 @@
 
 static struct IN_ADDR no_addr;
 
-/* error messages from gethostbyname() */
+/** \ingroup POD
+ *  error messages from gethostbyname() */
 static char *
 my_h_msgs(int x)
 {
@@ -180,6 +181,9 @@
 
 #define REQ_SZ 512
 
+/**
+ * \interface dnsserver "dnsserver.cc"
+ */
 static void
 lookup(const char *buf)
 {
@@ -260,6 +264,19 @@
     printf("\n");
 }
 
+/**
+ * \interface dnsserver "dnsserver.cc"
+ * \ingroup ExternalPrograms
+ *
+\verbatim
+usage: dnsserver -Dhv -s nameserver
+	-D             Enable resolver RES_DEFNAMES and RES_DNSRCH options
+	-h             Help
+	-v             Version
+	-s nameserver  Specify alternate name server(s).  'nameserver'
+	               must be an IP address, -s option may be repeated
+\endverbatim
+ */
 static void
 usage(void)
 {
Index: squid3/src/squid.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/squid.h,v
retrieving revision 1.33
retrieving revision 1.33.2.1
diff -u -r1.33 -r1.33.2.1
--- squid3/src/squid.h	24 Apr 2007 16:54:49 -0000	1.33
+++ squid3/src/squid.h	11 Jul 2007 03:14:59 -0000	1.33.2.1
@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.33 2007/04/24 16:54:49 squidadm Exp $
+ * $Id: squid.h,v 1.33.2.1 2007/07/11 03:14:59 amosjeffries Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -38,7 +38,9 @@
 #include "config.h"
 
 #ifdef _SQUID_MSWIN_
+/** \cond AUTODOCS-IGNORE */
 using namespace Squid;
+/** \endcond */
 #endif
 
 #include "assert.h"
Index: squid3/src/ssl_support.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/ssl_support.h,v
retrieving revision 1.6
retrieving revision 1.6.10.1
diff -u -r1.6 -r1.6.10.1
--- squid3/src/ssl_support.h	2 Sep 2006 15:50:26 -0000	1.6
+++ squid3/src/ssl_support.h	11 Jul 2007 03:14:59 -0000	1.6.10.1
@@ -1,6 +1,6 @@
 
 /*
- * $Id: ssl_support.h,v 1.6 2006/09/02 15:50:26 squidadm Exp $
+ * $Id: ssl_support.h,v 1.6.10.1 2007/07/11 03:14:59 amosjeffries Exp $
  *
  * AUTHOR: Benno Rice
  *
@@ -63,7 +63,9 @@
 
 #ifdef __cplusplus
 
+/** \cond AUTODOCS-IGNORE */
 namespace Squid {
+/** \endcond */
 
 inline
 int SSL_set_fd(SSL *ssl, int fd)
